import { useMutation, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider"
import { queryKeys } from "../query-keys";
import { LMComment } from "../../types";

export const useAddComment = () => {
    const {sendApiRequestAsync} = useAuth();
    const queryClient = useQueryClient()

    const createComment = async (commentValue: LMComment) => {
        if (commentValue) {
            const response = await sendApiRequestAsync({
                axiosConfig: {
                    method: 'POST',
                    data: commentValue,
                    url: `/api/comments/`,
                },
                authorized: true,
                errorMessage: 'Something went wrong when creating a comment',
                loggingCategory: 'COMMENTS',
            })
            response?.data
        }
    }

    return useMutation(createComment, {
        onSuccess: data => {
            queryClient.invalidateQueries(queryKeys.GET_COMMENTS)
        },  
    })
}
