import { useMutation, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";
import { API_URL } from "../../utils/RequestUtils";

export const useDeleteComment = () => {
    const {sendApiRequestAsync} = useAuth()
    const queryClient = useQueryClient()

    const removeComment =  async (id?: string | null) => {
        if (id) {
            const response = await sendApiRequestAsync({
                axiosConfig: {
                    method: 'DELETE',
                    url: API_URL + `/api/comments/${id}`,
                },
                authorized: true,
                errorMessage: 'Something went wrong when deleting a comment',
                loggingCategory: 'COMMENTS',
            });   
            return response?.data;
        }
    }

    return useMutation(removeComment, {
        onSuccess: () => queryClient.invalidateQueries(queryKeys.GET_COMMENTS),  
        onError: () => queryClient.invalidateQueries(queryKeys.GET_COMMENTS),  
    })
}