import { useMutation, useQueryClient } from "react-query"
import { useAuth } from "../../state/external/auth-provider"
import { queryKeys } from "../query-keys"
import { LMComment } from "../../types"

export const useEditComment = () => {
    const {sendApiRequestAsync} = useAuth()
    const queryClient = useQueryClient()

    const editComment =  async (commentValue: LMComment) => {
        if (commentValue) { 
            const response = await sendApiRequestAsync({
                axiosConfig: {
                    method: 'PUT',
                    data: {...commentValue, edited: true},
                    url: `/api/comments/`,
                },
                authorized: true,
                errorMessage: 'Something went wrong when editing a comment',
                loggingCategory: 'COMMENTS',
            })
            return response?.data;
        }
    }

    return useMutation(editComment, {
        onSuccess: () => queryClient.invalidateQueries(queryKeys.GET_COMMENTS),  
        onError: () => queryClient.invalidateQueries(queryKeys.GET_COMMENTS),  
    })
}