import { useQuery, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";
import { LMComment } from "../../types";
import { API_URL } from "../../utils/RequestUtils";

export const useLandmarkComments = (landmarkId: string) => {
    const {sendApiRequestAsync} = useAuth();
    const queryClient = useQueryClient();

    const getCommentsForLandmark = async (landmarkId: string) => {
        if (landmarkId) { 
    
                const response = await sendApiRequestAsync({
                    axiosConfig: {
                        method: 'GET',
                        url: `${API_URL}/api/comments/${landmarkId}`
                    },
                    authorized: false,
                    errorMessage: 'Something went wrong when retrieving comments',
                    loggingCategory: 'COMMENTS',
                });
                return response?.data?.reverse();
        }
    }

    return useQuery<LMComment[], Error>([queryKeys.GET_COMMENTS, landmarkId], async () => getCommentsForLandmark(landmarkId), {
        placeholderData: () => queryClient.getQueryData(queryKeys.GET_COMMENTS),
        staleTime: 1000,
        refetchInterval: 30000,
        refetchOnReconnect: true,
        refetchOnMount: false
    })
}