import { AxiosRequestConfig } from "axios";
import { useMutation, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";

export const useDeleteLandmark = () => {
    const {sendApiRequestAsync, accessToken, anonUserId} = useAuth()
    const queryClient = useQueryClient();

    const deleteLandmark =  async (id?: string) => {
        if (id) {
            const config: AxiosRequestConfig = {
                method: 'DELETE',
                url: `/api/landmark/${id}/`,
            }

            if (!accessToken) config.data = {...config.data, anonymous: anonUserId}


            const response = await sendApiRequestAsync({
                axiosConfig: config,
                authorized: true,
                errorMessage: 'Something went wrong when deleting a landmark',
                loggingCategory: 'LANDMARKS'
            });   
            return response?.data;
        }
    }

    return useMutation(deleteLandmark, {
        onSuccess: () => queryClient.invalidateQueries(queryKeys.GET_LANDMARKS),  
        onError: () => queryClient.invalidateQueries(queryKeys.GET_LANDMARKS),  
    })
}