import { AxiosRequestConfig } from "axios";
import { useMutation, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";
import { Landmark } from "../../types";

export const useEditLandmark = () => {
    const {sendApiRequestAsync, accessToken, anonUserId} = useAuth()
    const queryClient = useQueryClient();

    const editLandmark =  async (landmarkValue: Landmark) => {
        if (landmarkValue) {
            const config: AxiosRequestConfig = {
                method: 'PUT',
                url: `/api/landmark/`,
                data: {
                    landmark: landmarkValue
                }
            }

            if (!accessToken) {
                config.data = {...config.data, anonymous: anonUserId}
            }

            const response = await sendApiRequestAsync({
                axiosConfig: config, 
                authorized: true,
                errorMessage: 'Something went wrong when updating a landmark',
                loggingCategory: 'LANDMARKS'
            });   
            return response?.data;
        }
        else {
            console.warn("[LandmarkData]: Can't update landmark. Given landmark value is null.")
        }
    }

    return useMutation(editLandmark, {
        onSuccess: () => { queryClient.invalidateQueries(queryKeys.GET_LANDMARKS)},  
        onError: () => queryClient.invalidateQueries(queryKeys.GET_LANDMARKS),  
    })
}