import { useQuery, useQueryClient } from "react-query";

/**
 * Interface representing a landmark object
 */

import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";
import { Landmark } from "../../types";

/**
 * A custom hook containing [react-query]{@link https://react-query.tanstack.com/} queries and mutations and other logic related to interacting with {@link Landmark} objects.
 * @category Hooks
 * @namespace useLandmarks
 */
 export const useLandmarks = () => {
    const { sendApiRequestAsync } = useAuth();
    const queryClient = useQueryClient();

    const getLandmarks = async () => {
        const response = await sendApiRequestAsync({
           axiosConfig:  {
                method: 'GET',
                url: `/api/landmarks/`,
            }, 
            authorized: false,
            errorMessage: 'Something went wrong when retrieving landmarks',
            loggingCategory: 'LANDMARKS'
        });   
        return response?.data
    }

    return useQuery<Landmark[], Error>(queryKeys.GET_LANDMARKS, () => getLandmarks(), {
        placeholderData: () => queryClient.getQueryData(queryKeys.GET_LANDMARKS),
        staleTime: 1000,
        refetchInterval: 30000,
        refetchOnReconnect: true,
        refetchOnMount: false
    })
}