import { useQuery, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";
import { Landmark } from "../../types";

export const useLandmark = (landmarkId: string) => {
    const {sendApiRequestAsync, userId} = useAuth()
    const queryClient = useQueryClient();

     const getLandmark = async (landmarkId?: string) => {
        if (landmarkId) {
            const response = await sendApiRequestAsync({
                axiosConfig: {
                    method: 'GET',
                    url: `/api/landmark/${landmarkId}/`,
                },
                authorized: !!userId,
                errorMessage: 'Something went wrong when retrieving the landmark',
                loggingCategory: 'LANDMARKS'
            });   
            return response?.data 
        }
    }

    return useQuery<{landmark: Landmark, ratedByUser: boolean}, Error>([queryKeys.GET_LANDMARKS, landmarkId], () => getLandmark(landmarkId), {
        placeholderData: () => queryClient.getQueryData(queryKeys.GET_LANDMARKS),
        refetchOnReconnect: true,
        refetchOnMount: false
    })
}