import { useMutation, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";

export const useRateLandmark = () => {
    const {sendApiRequestAsync} = useAuth()
    const queryClient = useQueryClient();

    const rateLandmark =  async (data: {id: string, rating: 1 | -1}) => {
        if (data) {
            const response = await sendApiRequestAsync({
                axiosConfig:{
                    method: 'POST',
                    data: data,
                    url: `/api/landmark/rate/`,
                },
                authorized: true,
                errorMessage: 'Something went wrong when rating a landmark',
                loggingCategory: 'LANDMARKS'
            });   
            return response?.data?.rating;
        }
    }

    return useMutation(rateLandmark, {
        onSuccess: () => { 
            queryClient.invalidateQueries(queryKeys.GET_LANDMARKS)
        },  
        onError: () => queryClient.invalidateQueries(queryKeys.GET_LANDMARKS),  
    })    
}