import { AxiosRequestConfig } from "axios";
import { useMutation, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";
import { LMPhoto } from "../../types";

export const useAddLandmarkPhoto = () => {
    const {sendApiRequestAsync, accessToken, anonUserId} = useAuth()
    const queryClient = useQueryClient();

    const addLandmarkPhoto = async (photo: LMPhoto) => {
        if (photo) {
            const config: AxiosRequestConfig = {
                method: 'POST',
                url: `/api/landmark/photos/`,
                data: photo
            }
        
            if (!accessToken) config.data = {...config.data, anonymous: anonUserId}

            const response = await sendApiRequestAsync({
                axiosConfig: config, 
                authorized: true,
                errorMessage: 'Something went wrong when adding landmark photo',
                loggingCategory: 'LANDMARKS'
            });   
            return response?.data
        }
    }

    return useMutation(addLandmarkPhoto, {
        onSuccess: () => {
            queryClient.invalidateQueries(queryKeys.GET_LANDMARKS)
        },
        
        onError: () => {
            queryClient.invalidateQueries(queryKeys.GET_LANDMARKS)
        },
    })
}