import { AxiosRequestConfig } from "axios";
import { useMutation, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";

export const useDeleteLandmarkPhoto = () => {
    const {sendApiRequestAsync, accessToken, anonUserId} = useAuth()
    const queryClient = useQueryClient();

    const deleteLandmarkPhoto = async (photoId: string) => {
        if (photoId) {
            const config: AxiosRequestConfig = {
                method: 'DELETE',
                url: `/api/landmark/photos/${photoId}/`
            }

            if (!accessToken) {
                config.data = {...config.data, anonymous: anonUserId}
            }

            const response = await sendApiRequestAsync({
                axiosConfig: config,
                authorized: true,
                errorMessage: 'Something went wrong when deleting landmark photos',
                loggingCategory: 'LANDMARKS'
            });   
            return response?.data
        }
    }

    return useMutation(deleteLandmarkPhoto, {
        onSuccess: () => {
            queryClient.invalidateQueries(queryKeys.GET_LANDMARKS)
        },
        
        onError: () => {
            queryClient.invalidateQueries(queryKeys.GET_LANDMARKS)
        },
    })
}