import { useMutation, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";

export const useChangePassword = () => {
    const queryClient = useQueryClient();
    const {sendApiRequestAsync, userId} = useAuth()
    const changePassword = async (password: string) => {
        if (password && userId) { 
            const response = await sendApiRequestAsync({
                axiosConfig: {
                    method: 'POST',
                    url: `/api/user-profile/change-password/${userId}/`,
                    data: {password: password},
                }, 
                authorized: true,
                errorMessage: 'Something went wrong when changing password',
                loggingCategory: 'PROFILE',
            });   
            return response.data;
        }
    }

    return useMutation(changePassword, {
        onSuccess: () => { queryClient.invalidateQueries(queryKeys.GET_OWN_PROFILE)},  
        onError: () => queryClient.invalidateQueries(queryKeys.GET_OWN_PROFILE),  
    })
}