import { useAuth } from "../../state/external/auth-provider";
import { useOwnedProfile } from "./profiles.get-own";
import { useMutation, useQueryClient } from "react-query";
import { API_URL } from "../../utils/RequestUtils";
import { queryKeys } from "../query-keys";

export const useDeleteProfile = () => {
    const {clearProfile} = useOwnedProfile()
    const {clearAuthStorage} = useAuth()
    const queryClient = useQueryClient();
    const {sendApiRequestAsync, userId} = useAuth()

    const deleteProfile = async () => {
        if (userId) { 
            const response = await sendApiRequestAsync({
                axiosConfig: {
                    method: 'DELETE',
                    url: API_URL + `/api/user-profile/${userId}/`,
                },
                authorized: true,
                errorMessage: 'Something went wrong when deleting profile',
                loggingCategory: 'PROFILE',
            });   
            
            if (response.status == 200) {
                await clearProfile()
                await clearAuthStorage()
            }
        }
    }

    return useMutation(deleteProfile, {
        onSuccess: () => { queryClient.invalidateQueries(queryKeys.GET_OWN_PROFILE)},  
        onError: () => queryClient.invalidateQueries(queryKeys.GET_OWN_PROFILE),  
    })
}