import { useMutation, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { queryKeys } from "../query-keys";
import { RegisterCredsValues } from "../../utils/RegistrationUtils";
import { API_URL } from "../../utils/RequestUtils";

export const useEditProfile = () => {
    const queryClient = useQueryClient();
    const {sendApiRequestAsync, userId} = useAuth()

     const editProfile = async (values: RegisterCredsValues) => {
        const response = await sendApiRequestAsync({
            axiosConfig: {
                method: 'PUT',
                url: API_URL + `/api/user-profile/${userId}/`,
                data: values,
            },
            authorized: true,
            errorMessage: 'Something went wrong when editing profile',
            loggingCategory: 'PROFILE',
        });   
        return response.data;
    }
    return useMutation(editProfile, {
        onSuccess: () => { queryClient.invalidateQueries(queryKeys.GET_OWN_PROFILE)},  
        onError: () => queryClient.invalidateQueries(queryKeys.GET_OWN_PROFILE),  
    })
}