import { useQuery, useQueryClient } from "react-query";
import { useAuth } from "../../state/external/auth-provider";
import { UserProfile } from "../../types";
import { queryKeys } from "../query-keys";

/**
 * A custom hook containing [react-query]{@link https://react-query.tanstack.com/} queries and mutations and other logic related to interacting with {@link UserProfile} objects.
 * @category Hooks
 * @namespace useProfile
 */
 export const useOwnedProfile = () => {
    const queryClient = useQueryClient();
    const {sendApiRequestAsync, accessToken, userId} = useAuth()

    const getOwnedProfile = async () => {
        const response = await sendApiRequestAsync({
            axiosConfig: {
                method: 'GET',
                url: `/api/user-profile/${userId}/`,
            }, 
            authorized: true,
            errorMessage: 'Something went wrong when retrieving user profile',
            loggingCategory: 'PROFILE',
        });   
        return response.data;
    }

    const {data: profile} = useQuery<UserProfile, Error>(queryKeys.GET_OWN_PROFILE, getOwnedProfile, {
        enabled: !!userId && !!accessToken
    })

    const changeProfile = async (profile: UserProfile) => {
        queryClient.setQueriesData(queryKeys.GET_OWN_PROFILE, profile)
    }

    const clearProfile = async () => {
        queryClient.setQueryData(queryKeys.GET_OWN_PROFILE, null);
        queryClient.removeQueries();
    }

 return {profile, changeProfile, clearProfile}
}