import { useAuth } from "../../state/external/auth-provider";
import { useMutation, useQueryClient } from "react-query";
import { queryKeys } from "../query-keys";

export const useToggleTips = () => {
    const {sendApiRequestAsync, userId} = useAuth()
    const queryClient = useQueryClient();

    const toggleTips = async () => {
        if (userId) { 
            const response = await sendApiRequestAsync({
                axiosConfig: {
                    method: 'POST',
                    url: `/api/user-profile/toggle-tips/${userId}/`,
                },
                authorized: true,
                errorMessage: 'Something went wrong when toggling tips',
                loggingCategory: 'PROFILE',
            });   
            return response.data;
        }
    }

    return useMutation(toggleTips, {
        onSuccess: () => { queryClient.invalidateQueries(queryKeys.GET_OWN_PROFILE)},  
        onError: () => queryClient.invalidateQueries(queryKeys.GET_OWN_PROFILE),  
    })
}