import React, { useState } from "react"
import { View, ViewStyle } from "react-native"
import { Menu, MenuItem, MenuItemProps, MenuProps } from "react-native-material-menu"
import { colors } from "../utils/GlobalUtils"
import { IconButton } from "./Buttons"

interface HamburgerMenuItem {
    onPress: () => void
    text: string;
    disabled?: boolean;
    extraProps?: Omit<MenuItemProps, 'children'>;
}

interface BurgerMenuProps {
    menuItems: HamburgerMenuItem[];
    styles?: ViewStyle;
}

export const BurgerMenu: React.FC<BurgerMenuProps> = ({menuItems, styles}) => {
    const [visible, setVisible] = useState<boolean>();
    return (
        <View style={{ top: 100, right: 7.5, position: 'absolute'}}>
            <Menu
                visible={visible}
                anchor={<IconButton size={16} color={colors.red} style={styles} icon="bars" onPress={() => setVisible(true)} />}
                onRequestClose={() => setVisible(false)}>
                {menuItems.map(item => {
                    return <MenuItem {...item.extraProps} disabled={item.disabled} onPress={item.onPress}>{item.text}</MenuItem>
                })}
            </Menu>
        </View>
    )
}
    