import { FontAwesome } from "@expo/vector-icons";
import React from 'react';
import { StyleSheet, TouchableOpacity, View } from 'react-native';
import { store } from "../../../main-store";
import { colors } from "../../../utils/GlobalUtils";

interface FloorChangeButtonProps {
  floorChange: -1 | 1 | 0;
}

const FloorChangeButton: React.FC<FloorChangeButtonProps> = ({floorChange}) => {
  const icon = (() => floorChange == 1 ? "chevron-right" : floorChange == -1 ? "chevron-left" : "")();
  const iconMargin = (() => store.mapIndoor.floorNumber == 1 ? 5: -5)();

  if (store.mapIndoor.floorNumber != 0) {
      return (
          <TouchableOpacity style={styles.arrowButton} onPress={() => store.mapIndoor.changeFloor(floorChange)} >
            <View style={{ flex: 1, justifyContent: "center", alignItems: "center" }}>
              <FontAwesome style={{ marginLeft: iconMargin }} color={"white"} size={20} name={icon as any} />
            </View>
          </TouchableOpacity>
      )
    }
    else {
      return (
        <View style={{ flex: 1.2, marginHorizontal: 7, height: 53.5, maxWidth: 60, borderRadius: 10 }}/>
      )
    }
}


const styles = StyleSheet.create({
    arrowButton: {
        flex: 1,
        backgroundColor: colors.red,
        height: 53.5,
        borderRadius: 8,
      },
})



export default FloorChangeButton