import ReactNativeZoomableView from '@openspacelabs/react-native-zoomable-view/src/ReactNativeZoomableView';
import React, { useState } from 'react';
import { Alert, Dimensions, GestureResponderEvent, ImageSourcePropType, Linking, StatusBar, StyleSheet, View } from 'react-native';
import Picker from 'react-native-picker-select';
import Toast from 'react-native-root-toast';
import { Image, Svg } from 'react-native-svg';
import { useLandmarks } from '../../../api/landmarks';
import { store } from "../../../main-store";
import { Landmark } from "../../../types";
import { colors, lmTypesIndoor } from "../../../utils/GlobalUtils";
import { BurgerMenu } from '../../burger-menu';
import FloorChangeButton from "./floor-change-button";
import IndoorFloor from './indoor-floor';

const UALBERTA_EMERG = 'https://www.ualberta.ca/facilities-operations/portfolio/emergency-management-office/emergency-procedures/alarms-evacuation.html'
const UALBERTA_HOME = 'https://www.library.ualberta.ca/'

const landmarkPinSize = 0.05 * Dimensions.get("window").width;

const IndoorMap: React.FC = () => {
  const [floor, setFloor] = useState(1);
  const [SVGdim, setSVGdim] = useState([1, 1])
  const [localLandmarks, setLocalLandmarks] = useState<Landmark[]>([])
  const {data: landmarks} = useLandmarks();

  const renderedLandmarks = applyFilter(landmarks)?.filter(lm => lm.floor == floor && lmTypesIndoor[lm.landmark_type]).map((lm) => {
    console.log(landmarks[0])
    if (SVGdim[0] != 1 && SVGdim[1] != 1) {
      return (
        <Image
          onPress={() => focusLandmark(lm)}
          key={lm.id}
          x={lm.longitude * SVGdim[0]}
          y={lm.latitude * SVGdim[1]}
          width={landmarkPinSize}
          height={landmarkPinSize}
          href={lmTypesIndoor[lm.landmark_type].image as ImageSourcePropType} />
      )
    }
  })

  
  console.log(landmarks.length, renderedLandmarks.length)


  function addLandmark(evt: GestureResponderEvent) {
    if (evt != null) {
      Alert.alert("Are you sure you want to add a landmark here?", undefined,
        [{ text: "Cancel" }
          ,
        {
          text: "Confirm", onPress: async () => {
            try {
              await promptAddLandmark((evt.nativeEvent.locationX - landmarkPinSize / 2) / SVGdim[0], (evt.nativeEvent.locationY - landmarkPinSize / 2) / SVGdim[1], floor)
            }
            catch (err) {
              Toast.show("Please ensure finger is not moving when holding down on screen.", { duration: Toast.durations.LONG, })

              // Alert.alert("An error has occured." , "Please ensure thumb is not moving when holding down on screen.")
              // consider toast
            }
          }
        }]
      )
    }
  }

  const childToWeb = (child: any) => {
    const { type, props } = child;
    const name = type && type.displayName;
    const webName = name && name[0].toLowerCase() + name.slice(1);
    const Tag = webName ? webName : type;
    return <Tag {...props}>{toWeb(props.children)}</Tag>;
  };

  const leftFloorChange = (() => store.mapIndoor.floorNumber == 0 ? 0 : -1)()
  const rightFloorChange = (() => store.mapIndoor.floorNumber == 5 ? 0 : 1)()

  const toWeb = (children: any) => React.Children.map(children, childToWeb);
  function changer(num) {
    setFloor(prevState => prevState + num)
  }

  // TODO: wire up promptaddlandmark, applyfilters, and focuslandmark methods passed from MapNavigator
  return (
    <View style={{ height: '100%', width: Dimensions.get("screen").width, backgroundColor:colors.red }}>
      <BurgerMenu 
        styles={{top: 100, right: 7.5, position: 'absolute'}}
        menuItems={[
          {onPress: () => navigate("Outdoor"), text: 'Go Back Outdoors'},
          {onPress: () => Linking.openURL(UALBERTA_EMERG), text: 'Emergency Procedures'},
          {onPress: () => Linking.openURL(UALBERTA_HOME), text: 'Resources'}
        ]}/>

      <StatusBar backgroundColor={colors.red} />
      {/* <CustomModal /> */}
      {/* <Text style={{ fontSize: 16, marginBottom: 5 }}>Please select a floor you would like to go to.</Text> */}

      <View style={{ borderColor: "blue", borderWidth: 0, maxHeight: 50, flex: 1, flexDirection: "row", justifyContent: "center", }}>

        <FloorChangeButton floorChange={leftFloorChange} />

        <View style={{flex: 5, height: 53.5, width: 200 }}>
          <Picker
            placeholder={{}}
            value={floor}
            style={{ 
              inputIOSContainer: {width:'70%', justifyContent: 'center', alignSelf: 'center'},
              inputAndroid: {textAlign: 'center', color:"white", },
              inputIOS: { color: 'white', textAlign: 'center', height: '100%', alignSelf: 'center'} ,
              iconContainer: {height: '100%', justifyContent: 'center',}
            }}
            onValueChange={(value) => {
              setFloor(value)
            }
            }
            items={[
              { label: 'Basement', value: 0 },
              { label: 'First Floor', value: 1 },
              { label: 'Second Floor', value: 2 },
              { label: 'Third Floor', value: 3 },
              { label: 'Fourth Floor', value: 4 },
              { label: 'Fifth Floor', value: 5 },
            ]}
          />
        </View>

        <FloorChangeButton floorChange={rightFloorChange} />


      </View>

      <View style={{ flex: 1, alignItems: "center", height: '100%', width: '100%', borderColor: 'purple', borderWidth: 0 }}>
        <View style={styles.container}>
          {/* {showME === false ?
            <View style={{ display: 'flex', flexDirection: 'row', justifyContent: "center", }}>
              <ActivityIndicator color={colors.red} size="large" />
            </View> : */}

            <ReactNativeZoomableView
              panBoundaryPadding={100}
              bindToBorders={true}
              zoomStep={2.8}
              maxZoom={5}
              minZoom={1}
              initialOffsetY={5}
              onLongPress={(event) => addLandmark(event)}
              movementSensibility={2}
              longPressDuration={200}
              >

              <Svg onLayout={event => {
                setSVGdim([event.nativeEvent.layout.width, event.nativeEvent.layout.height])
                const transformedLandmarks = localLandmarks.map(item => {
                  return { ...item, coordx: item.longitude * event.nativeEvent.layout.width, coordy: item.latitude * event.nativeEvent.layout.height }
                })
                //console.log("*this is within onLayout* SVGdim values are " + SVGdim[0] + " AND " + SVGdim[1])
                setLocalLandmarks(transformedLandmarks)
              }}
              >
                {/* {firstTime == true ? undefined : loadCircles} */}
                <IndoorFloor floorNum={floor} />
                {renderedLandmarks}
              </Svg>
            </ReactNativeZoomableView>
          {/* } */}

        </View>
      </View>
    </View >
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    // backgroundColor: "#fff",
    justifyContent: "center",
    borderColor: "black",
    borderWidth: 0,
    marginVertical: 0,
    aspectRatio: 8 / 10,  // (caters to portrait mode) (width is 80% the value of height dimension)
    width: '100%',
    height: '100%',
    maxWidth: "100%",
    maxHeight: "100%",
    backgroundColor:"white",
    
  },
  image: {
    alignItems: 'center',
    justifyContent: 'center',
  },
  png: {
    borderColor: "red",
    borderWidth: 3
  },
  arrowButton: {
    flex: 1,
    backgroundColor: colors.red,
    height: 53.5,
  },
});


export default IndoorMap;