import { ImageInfo } from "expo-image-picker";
import { useEffect, useRef, useState } from "react";
import ViewShot, { captureRef } from "react-native-view-shot";
import { useAddLandmark } from "../../../../api/landmarks/landmark.add";
import { store } from "../../../../main-store";
import { LMPhoto } from "../../../../types";
import { lmTypes, lmTypesIndoor } from "../../../../utils/GlobalUtils";

export const useAddLandmarkApi = () => {
    const [currentRoute, setCurrentRoute] = useState<string>();
    const addLandmarkMutation = useAddLandmark();
    const lmLocationScreenCap = useRef<ViewShot>()
    
    let currentLmTypes = lmTypes;
    if (currentRoute=="Indoor") {
        currentLmTypes = lmTypesIndoor;
    }

    useEffect(() => {
        /**
         * Resets the {@link addLandmarkAsync} mutation on successful add.
         * Embedded in a useEffect that listens to the {@link addLandmarkStatus} value from the {@link useLandmarks} hook.
         * @memberOf AddLandmark
         */
        const resetAddMutationOnSuccess = () => {
            if (addLandmarkMutation.isSuccess) {
                addLandmarkMutation.reset()
            }
        }
        resetAddMutationOnSuccess();
    }, [addLandmarkMutation.status]);

    useEffect(() => {
        addLandmarkMutation.reset();
    }, [store.addLm.panelVisible]);

    /**
     * Calls {@link addLandmarkAsync} from {@link useLandmarks} to initate the process of adding a landmark, then closes the modal.
     */
    const submit = async () => {
        if (typeof store.addLm.pendingLandmark.floor === 'number') {
            try {
                const uri = await captureRef(lmLocationScreenCap, {
                    format: "jpg",
                    quality: 1,
                    result: 'base64'
                })

                await addLandmarkMutation.mutateAsync({ landmark: store.addLm.pendingLandmark, photos: store.addLm.photos, indoorMapSnapshotBase64: uri }); // pass it in here


            } catch (error) {
                console.error("Oops, snapshot failed", error);
            }
        }
        else {
            await addLandmarkMutation.mutateAsync({ landmark: store.addLm.pendingLandmark, photos: store.addLm.photos });
        }

        store.addLm.close();
    }
    
    return {addLandmarkMutation, submit, lmLocationScreenCap}
}