import { makeAutoObservable } from "mobx";

export type FilterType = 'min-rating' | 'only-owned' | 'landmark-types'
export type FilterValueType = number | number[] | boolean
export type FilterMap = Record<FilterType, FilterValueType>

export class FilterStore {
    // use a dictionary for filters to allow for easier batched updates
    current: FilterMap = {
        'min-rating': 0,
        'only-owned': false,
        'landmark-types': [] 
    }

    panelVisible = false;

    constructor() {
        makeAutoObservable(this);
    }

    openPanel() {this.panelVisible = true}
    closePanel() {this.panelVisible = false}

    setFilters(changes: {type: FilterType, value: FilterValueType}[]) {
        changes.forEach(change => {
            this.current[change.type] = change.value;
        })
    }
}