﻿/* Copyright (C) Click & Push Accessibility, Inc - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written and maintained by the Click & Push Development team 
 * <dev@clicknpush.ca>, January 2022
 */

import { FontAwesome } from "@expo/vector-icons";
import React, { memo, useState } from "react";
import { Dimensions, Image, SafeAreaView, Text, TouchableOpacity, View } from 'react-native';
import { ScrollView } from "react-native-gesture-handler";
import Modal from 'react-native-modal';
import { store } from "../../../../main-store";
import { Landmark } from "../../../../types";
import { colors, lmTypes } from "../../../../utils/GlobalUtils";

/**
 * Component that renders a form for adding a new {@link Landmark}. Contained within a [react-native-modal]{@link https://github.com/react-native-modal/react-native-modal}.
 * @component
 * @category Map
 */

const NearbyLandmarksPanel: React.FC = ({}) => {
    return (
        <Modal
            useNativeDriver={true}
            useNativeDriverForBackdrop={true}
            onBackdropPress={() => store.nearbyLm.closePanel()}
            style={{justifyContent: "flex-end", height: '100%', margin: 0}}
            isVisible={store.nearbyLm.panelVisible} >
            <SafeAreaView style={{backgroundColor: colors.red, height: Dimensions.get('window').height * .6}}>
                <ScrollView>
                    {store.nearbyLm.nearbyLandmarks?.map((lm, i) => {
                        return (
                            <TouchableOpacity onPress={() => store.selectedLm.selectLandmark(lm.id)} key={i} style={{flexDirection: 'row', alignItems: 'center', paddingVertical: 10, marginHorizontal: 15, justifyContent: 'space-between', borderBottomWidth: 1, borderColor: 'lightgray'}}>
                                <Image source={lmTypes[lm.landmark_type].image}/>
                                <Text style={{fontSize: 20, color: 'white'}}>{lmTypes[lm.landmark_type].label.toUpperCase()}</Text>
                                <View style={{flexDirection: 'row', alignItems: 'center'}}>
                                    <Text style={{marginRight: 5, color: 'white', fontSize: 20}}>{lm.rating}</Text>
                                    <FontAwesome name="thumbs-up" size={20} color='white' />
                                </View>
                            </TouchableOpacity>
                        )
                    })}
                </ScrollView>
            </SafeAreaView>
        </Modal>
    )
}

export default memo(NearbyLandmarksPanel);