import { useEffect } from "react"
import { useAddLandmark } from "../../../../api/landmarks";
import { store } from "../../../../main-store";
import { useAuth } from "../../../../state/external/auth-provider";

export const useVoicePanelApi = () => {
    const addLandmarkMutation = useAddLandmark();
    const {setAlert} = useAuth();
    useEffect(() => {(async () => {
        if (store.voice.action.step == 3 && store.voice.lastSaid.includes("yes")) {   
            await addLandmarkMutation.mutateAsync({landmark: store.addLm.pendingLandmark});
        }
        
        store.voice.action = undefined;                
    })()}, [store.voice.action])

    useEffect(() => {
        /**
         * Resets the {@link addLandmarkAsync} mutation, and reports to the user on successful add. Reports error on failure.
         * Embedded in a useEffect that listens to the {@link addLandmarkStatus} value from the {@link useLandmarks} hook.
         * @memberOf AddLandmark
         */
        const finishAddAttempt = async () => {
            if (addLandmarkMutation.isSuccess) {
                addLandmarkMutation.reset();
                setAlert({
                    title: "Added landmark", 
                    message: "Landmark added successfully", 
                    type: "success",
                })
            }
            else if (addLandmarkMutation.isError) {
                // TODO: actually handle error here
                
            }
        }
        finishAddAttempt();
    }, [addLandmarkMutation.status]);

    return {addLandmarkMutation};
}