﻿/* Copyright (C) Click & Push Accessibility, Inc - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written and maintained by the Click & Push Development team 
 * <dev@clicknpush.ca>, January 2022
 */

import { createStackNavigator, StackNavigationProp } from '@react-navigation/stack';
import React from "react";
import { RegisterMain } from '../profile/Registration/RegisterMain';
import MainTabsNavigator from './main-tabs-navigator';

/**
 * Permitted screens for the Auth stack navigator. 
 * @category Navigation
 * @typedef
 */
export type BaseStackParamList = {
    MainTabs: React.FC,
    Register: React.FC,
}

export type BaseStackNavigationProp = StackNavigationProp<BaseStackParamList>;

const BaseStack = createStackNavigator<BaseStackParamList>();

/**
 * The root navigator for all unauthorized screens ({@link Intro}, {@link RegisterMain}). It uses a [React Navigation Stack Navigator]{@link https://reactnavigation.org/docs/stack-navigator/} the main navigation mechanism.
 * @category Navigation
 * @component
 */
const BaseStackNavigator : React.FC = () => {
    return (
        <BaseStack.Navigator screenOptions={{
            headerTransparent: true,
            headerTintColor: 'white',
            headerTitle: ""}}>
            <BaseStack.Screen name="MainTabs" >
                {({navigation}) => <MainTabsNavigator />}
            </BaseStack.Screen>
            <BaseStack.Screen name="Register" component={RegisterMain} />
        </BaseStack.Navigator>
    );
}

export default BaseStackNavigator;